==> haskell-distributive-0.6.2.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-EHQ3J6aMOyRBCk61DhPvaD
key:                  distributive-0.6.2.1-EHQ3J6aMOyRBCk61DhPvaD
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  1df483acaad2d7b6d001b066c07ff0f5
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-8.10.3/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/distributive-0.6.2.1
hs-libraries:         HSdistributive-0.6.2.1-EHQ3J6aMOyRBCk61DhPvaD
depends:
    base-4.14.1.0 base-orphans-0.8.4-JVHjiBgNsq01QI8Dg9yJ1
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6.2.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-JWdsLTFaWjBEZcHvdaRTay
key:                  distributive-0.6.2.1-JWdsLTFaWjBEZcHvdaRTay
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  d15e15051ba32aff5dd99c25dc306522
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-8.10.3/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/distributive-0.6.2.1
hs-libraries:         HSdistributive-0.6.2.1-JWdsLTFaWjBEZcHvdaRTay
depends:
    base-4.14.1.0 base-orphans-0.8.4-5WjlP4Jw2We4qwFUhnErGg
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
